import { JobDates, iTwinCaptureError, iTwinCaptureWarning } from "@itwin/reality-capture-common";
/** Possible types of a Reality Modeling job. */
export declare enum CCJobType {
    NONE = "not recognized",
    CALIBRATION = "Calibration",
    RECONSTRUCTION = "Reconstruction",
    FULL = "Full"
}
/**
 * Properties of a workspace.
 * Convenience interface to stock all properties of a job in a simple way.
 */
export interface CCWorkspaceProperties {
    id: string;
    createdDateTime: string;
    name: string;
    iTwinId: string;
    contextCaptureVersion?: string;
}
/**
 * Parameters for estimating job cost before its processing.
 */
export interface CCCostParameters {
    gigaPixels?: number;
    megaPoints?: number;
    meshQuality?: CCJobQuality;
}
/**
 * Properties of a Reality Modeling job.
 * Convenience interface to stock all properties of a job in a simple way.
 */
export interface CCJobProperties {
    name: string;
    type: CCJobType;
    settings: CCJobSettings;
    workspaceId: string;
    iTwinId: string;
    id: string;
    location?: string;
    email?: string;
    state?: string;
    dates?: JobDates;
    exitCode?: string;
    executionCost?: string;
    costEstimationParameters?: CCCostParameters;
    estimatedCost?: string;
    errors: iTwinCaptureError[];
    warnings: iTwinCaptureWarning[];
}
/** Possible qualities of a Reality Modeling job. */
export declare enum CCJobQuality {
    UNKNOWN = "Unknown",
    DRAFT = "Draft",
    MEDIUM = "Medium",
    EXTRA = "Extra"
}
/**
 * Cache settings for a Reality Modeling Job.
 */
export interface CCCacheSettings {
    createCache: boolean;
    useCache: string;
}
/**
 * Possible outputs for a Reality Modeling job.
 */
declare class CCOutputs {
    /** Created context scene id. */
    contextScene: string;
    /** Created ccorientation id. */
    orientations: string;
    /** Created 3MX id. */
    threeMX: string;
    /** Created 3SM id. */
    threeSM: string;
    /** Created web ready scalable mesh id. */
    webReadyScalableMesh: string;
    /** Created cesium 3D tiles id. */
    cesium3DTiles: string;
    /** Created pod id. */
    pod: string;
    /** Created orthophoto id. */
    orthophoto: string;
    /** Created las id. */
    las: string;
    /** Created fbx id. */
    fbx: string;
    /** Created obj id. */
    obj: string;
    /** Created esri i3s id. */
    esri: string;
    /** Created dgn id. */
    dgn: string;
    /** Created load tree export id. */
    lodTreeExport: string;
    /** Created ply id. */
    ply: string;
    /** Created opc id. */
    opc: string;
    /** Created omr id. */
    omr: string;
    constructor();
}
/** Settings for Reality Modeling jobs. */
export declare class CCJobSettings {
    /** Possible inputs for this job. Should be the ids of the inputs in the cloud. */
    inputs: string[];
    /**
     * Possible outputs for this job.
     * Fill the outputs you want for the job with a string (normally the name of the output) before passing it to createJob.
     */
    outputs: CCOutputs;
    /** Mesh quality for this job. */
    meshQuality?: CCJobQuality;
    /** Quantity of engines to be used by the job. If set at 0, the job will use your engine limit. */
    engines?: number;
    /** Cache settings for this job. */
    cacheSettings?: CCCacheSettings;
    constructor();
    /**
     * Transform settings into json.
     * @returns {any} json with settings values.
     */
    toJson(): any;
    /**
     * Transform json received from cloud service into settings.
     * @param {any} jobJson Dictionary with settings received from cloud service.
     * @returns {CCJobSettings} New settings.
     */
    static fromJson(settingsJson: any): Promise<CCJobSettings>;
}
export {};
//# sourceMappingURL=Utils.d.ts.map