import { JobProgress } from "@itwin/reality-capture-common";
import { CCCostParameters, CCJobProperties, CCJobSettings, CCJobType, CCWorkspaceProperties } from "./Utils";
/**
 * Service handling communication with Reality Modeling Service
 */
export declare class ContextCaptureService {
    /** Callback to get an access token */
    private getAccessToken;
    /** Target service url. */
    private serviceUrl;
    /**
     * Create a new ContextCaptureService.
     * @param {() => Promise<string>} getAccessToken Callback to get an access token.
     * @param {string} env (optional) Target environment.
     */
    constructor(getAccessToken: () => Promise<string>, env?: string);
    /**
     * @private
     * @param {string} apiOperationUrl API operation url.
     * @param {string} method HTTP method.
     * @param {unknown} payload (optional) Request body.
     * @returns {any} Request response.
     */
    private submitRequest;
    /**
     * Get scopes required for this service.
     * @returns {Set<string>} Set of required minimal scopes.
     */
    static getScopes(): Set<string>;
    /**
     * Create a workspace corresponding to the given parameters.
     * @param {string} name Workspace name.
     * @param {string} iTwinId iTwinId associated to the workspace.
     * @param {string} contextCaptureVersion (optional) Version of Reality Modeling to be used for this workspace.
     * @returns {string} created workspace id.
     */
    createWorkspace(name: string, iTwinId: string, contextCaptureVersion?: string): Promise<string>;
    /**
     * Delete a workspace.
     * @param {string} workspaceId The ID of the relevant workspace.
     */
    deleteWorkspace(workspaceId: string): Promise<void>;
    /**
     * Get a workspace.
     * @param {string} workspaceId The ID of the relevant workspace.
     * @returns {CCWorkspaceProperties} Workspace properties.
     */
    getWorkspace(workspaceId: string): Promise<CCWorkspaceProperties>;
    /**
     * Create a job corresponding to the given settings.
     * @param {CCJobType} type Job type.
     * @param {CCJobSettings} settings Settings for the job.
     * @param {string} name Name for the job.
     * @param {string} workspaceId Workspace associated to this job.
     * @returns {string} Created job id.
     */
    createJob(type: CCJobType, settings: CCJobSettings, name: string, workspaceId: string): Promise<string>;
    /**
     * Submit a job.
     * @param {string} jobId The ID of the relevant job.
     */
    submitJob(jobId: string): Promise<void>;
    /**
     * Cancel a job.
     * @param {string} id The ID of the relevant job.
     */
    cancelJob(id: string): Promise<void>;
    /**
     * Delete a job.
     * @param {string} id The ID of the relevant job.
     */
    deleteJob(id: string): Promise<void>;
    /**
     * Get progress for a given job.
     * @param {string} id The ID of the relevant job.
     * @returns {JobProgress} The progress for the job.
     */
    getJobProgress(id: string): Promise<JobProgress>;
    /**
     * Get all properties for a given job.
     * @param {string} id The ID of the relevant job.
     * @returns {RDAJobProperties} The job properties.
     */
    getJobProperties(id: string): Promise<CCJobProperties>;
    /**
     * Get the estimated cost of a given job.
     * @param {string} id The ID of the relevant job.
     * @returns {number} The job cost estimation.
     */
    getJobEstimatedCost(id: string, costParameters: CCCostParameters): Promise<number>;
}
//# sourceMappingURL=ContextCaptureService.d.ts.map